pilas.escena.escena_normal.Aviso

Package pilas :: Package escena :: Module escena_normal :: Class Aviso |
[hide private]
[frames] | no frames]

# Class Aviso

source code

          object --+
                   |
    escena_base.Base --+
                       |
                      Aviso

Escena básica de pilas. Si no se define ninguna escena, cuando se ejecuta:

    >>> pilas.iniciar()
    >>> pilas.ejecutar()

esta es la escena que se muestra en la pantalla.

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see help(type(x)) for signature | source code
iniciar(self) Este método debe ser reimplementado en todas las clases que hereden de ella. | source code
salir(self, evento) | source code
actualizar(self) | source code
Inherited from `escena_base.Base`: `pausar`, `reanudar` Inherited from `escena_base.Base` (private): `_actualizar_eventos`, `_actualizar_fisica`, `_limpiar`, `_pausar_fisica`, `_reanudar_fisica` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### iniciar(self) | source code
Este método debe ser reimplementado en todas las clases que hereden de ella.
    >>>    def iniciar(self):
    >>>        fondo = pilas.fondos.Color(pilas.colores.grisclaro)
Overrides: escena_base.Base.iniciar (inherited documentation)